<?php

namespace Litecms\Coupon\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Coupon\Models\Coupons;

class CouponsPolicy
{

    /**
     * Determine if the given user can view the coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function view(UserPolicy $user, Coupons $coupons)
    {
        if ($user->canDo('coupon.coupons.view') && $user->isAdmin()) {
            return true;
        }

        return $coupons->user_id == user_id() && $coupons->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupon.coupons.create');
    }

    /**
     * Determine if the given user can update the given coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function update(UserPolicy $user, Coupons $coupons)
    {
        if ($user->canDo('coupon.coupons.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupons->user_id == user_id() && $coupons->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Coupons $coupons)
    {
        return $coupons->user_id == user_id() && $coupons->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Coupons $coupons)
    {
        if ($user->canDo('coupon.coupons.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coupons.
     *
     * @param UserPolicy $user
     * @param Coupons $coupons
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Coupons $coupons)
    {
        if ($user->canDo('coupon.coupons.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
